MESMER-OpenSCM Runner
=====================

Coupling between `MESMER <https://github.com/MESMER-group/mesmer>`_ and `OpenSCM-Runner <https://github.com/openscm/openscm-runner>`_.

.. sec-begin-license

License
-------

Copyright (c) 2021 MESMER-OpenSCM Runner contributors, listed in AUTHORS, and ETH Zurich.

MESMER-OpenSCM Runner is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License (see `LICENSE <https://github.com/MESMER-group/mesmer-openscmrunner/blob/master/LICENSE>`_), or
(at your option) any later version.

MESMER-OpenSCM Runner is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

The full list of code contributors can be found in AUTHORS or at
`github.com/MESMER-group/mesmer-openscmrunner/graphs/contributors <https://github.com/MESMER-group/mesmer-openscmrunner/graphs/contributors>`_.

.. sec-end-license
